@@ -23,14 +23,14 @@
 #' # Discrete scale
 #' example_data_wide |>
 #'   subset(crop %in% c("Apple", "Cherry", "Potato")) |>
-#'   ggplot(aes(x = pH, y = Mn_mg.kg, color = crop)) +
+#'   ggplot(aes(x = ph, y = mn_mg_kg, color = crop)) +
 #'   geom_point(size = 2.5) +
 #'   theme_minimal() +
 #'   washi_scale()
 #'
 #' # Continuous scale
 #' example_data_wide |>
-#'   ggplot(aes(x = `totalC_%`, y = poxC_mg.kg, color = poxC_mg.kg)) +
+#'   ggplot(aes(x = total_c_percent, y = poxc_mg_kg, color = poxc_mg_kg)) +
 #'   geom_point(size = 2.5) +
 #'   theme_minimal() +
 #'   washi_scale("green_gradient", reverse = TRUE, discrete = FALSE)
@@ -42,7 +42,7 @@ washi_scale <- function(
   reverse = FALSE,
   discrete = TRUE,
   ...
-    ) {
+) {
   pal <- washi_pal_setup(palette = palette, reverse = reverse)
 
   if (alpha < 0 | alpha > 1) {
@@ -50,9 +50,7 @@ washi_scale <- function(
   }
 
   if (!is.logical(discrete)) {
-    cli::cli_abort(c(
-      "`discrete` must be `TRUE` or `FALSE`."
-    ))
+    cli::cli_abort("`discrete` must be `TRUE` or `FALSE`.")
   }
 
   pal <- scales::alpha(pal, rep_len(alpha, length(pal)))
@@ -62,7 +60,6 @@ washi_scale <- function(
   if (discrete == TRUE) {
     ggplot2::discrete_scale(
       aesthetics = aesthetics,
-      scale_name = paste0("washi_", palette),
       palette = scales::manual_pal(pal),
       ...
     )
