@@ -9,22 +9,17 @@ test_that("washi_scale() works", {
   )
 
   # Check that a ggplot object is returned
-  data <- data.frame(a = 1:5,
-                     b = 6:10,
-                     c = c(rep("a", 2), rep("b", 2), "c"))
+  data <- data.frame(a = 1:5, b = 6:10, c = c(rep("a", 2), rep("b", 2), "c"))
 
   # Check that a ggplot object is returned
   plot <- ggplot2::ggplot(
     data,
-    ggplot2::aes(x = a,
-                 y = b,
-                 color = c
-    )
+    ggplot2::aes(x = a, y = b, color = c)
   ) +
     ggplot2::geom_point() +
     washi_scale()
 
-  expect_true(ggplot2::is.ggplot(plot))
+  expect_true(ggplot2::is_ggplot(plot))
 
   # Check that alpha > 1 errors
   expect_error(
@@ -39,6 +34,5 @@ test_that("washi_scale() works", {
   )
 
   # Check a snapshot
-  vdiffr::expect_doppelganger(title = "washi_scale",
-                              fig = plot)
+  vdiffr::expect_doppelganger(title = "washi_scale", fig = plot)
 })
